rm(list=ls())

library(dplyr)

#input original data file
setwd("C:/Users/ejgangloff/Box/BronikoLabExperiments/TelegansMultiplePaternity/2020Revision")
LitterData <-read.table("BabyData_29June2020.csv", header=T, sep = ",", as.is=T)

#Eliminate unused columns
LitterData <- subset(LitterData, select = -c(Yolks, PreviousID, X, Live.SB, w.ipopdad, Ecotype))

#Assign ecotypes
LitterData$Ecotype[LitterData$Population == "ELFS"] <- "Lfast"
LitterData$Ecotype[LitterData$Population == "PK"] <- "Lfast"
LitterData$Ecotype[LitterData$Population == "WC"] <- "Lfast"
LitterData$Ecotype[LitterData$Population == "MH"] <- "Mslow"
LitterData$Ecotype[LitterData$Population == "NL"] <- "Mslow"
LitterData$Ecotype[LitterData$Population == "PA"] <- "Mslow"

#Rename populations
LitterData$Population[LitterData$Population == "ELFS"] <- "L4"
LitterData$Population[LitterData$Population == "PK"] <- "L2"
LitterData$Population[LitterData$Population == "WC"] <- "L3"
LitterData$Population[LitterData$Population == "MH"] <- "M3"
LitterData$Population[LitterData$Population == "NL"] <- "M2"
LitterData$Population[LitterData$Population == "PA"] <- "M1"

#Need to add SVL
#input Mom SVL data file
setwd("C:/Users/ejgangloff/Box/BronikoLabExperiments/TelegansMultiplePaternity/2020Revision")
MomSVLData <-read.table("MomSVLData.csv", header=T, sep = ",", as.is=T)
str(MomSVLData)

LitterData <- merge(LitterData, MomSVLData, by = "Mom", all.x = T, all.y = F)
str(LitterData)

LitterData <- LitterData[LitterData$BabyID != "SB1",]
LitterData$SampledLitterSize[LitterData$Mom == 230] <- 9

#Eliminate litters with < 55% sampled
#Let's phrase this as 'majority of offspring genotyped (> 50%)'
LitterData <- LitterData[LitterData$PropSampled > 0.55,]

LitterData$PropSampledTest <- LitterData$SampledLitterSize/(LitterData$Neonate + LitterData$Stillborns)
#LitterData$PropSampledTest <- LitterData$PropSampledTest - LitterData$PropSampled
LitterData$PropSampledTest

#Checks out (differences due to rounding)

#Does prop sampled include stillborns?
#Yes, I think it does
str(LitterData)

#LitterData$PropSampled <- LitterData$SampledLitterSize/LitterData$TotalLitterSize
hist(LitterData$PropSampledTest)
#Can Eliminate column "PropSampled"
LitterData <- subset(LitterData, select = -PropSampled)

#Reduce data to moms and populations
str(LitterData)
MomsData <- LitterData[,c(1,2,8,9,10,11,12,13)]
MomsData <- distinct(MomsData)
str(MomsData)

MomsData$PropSampled <- MomsData$SampledLitterSize/(MomsData$Neonate + MomsData$Stillborns)
mean(MomsData$PropSampled)

str(LitterData)

#Can Eliminate column "PropSampledTest" (since this is calculated with other data)
LitterData <- subset(LitterData, select = -PropSampledTest)

#Export .csv for archiving
setwd("C:/Users/ejgangloff/Box/BronikoLabExperiments/TelegansMultiplePaternity/2020Revision/JoH.Resubmission.Mar.2021/Revision-June-2021/Data Archive")
write.table(LitterData, file="TelegansReproductiveData.csv", sep=",", quote=FALSE, row.names = FALSE)

####Re-run analyses####
#with archived data frame to verify
rm(list=ls())
setwd("C:/Users/ejgangloff/Box/BronikoLabExperiments/TelegansMultiplePaternity/2020Revision/JoH.Resubmission.Mar.2021/Revision-June-2021/Data Archive")
LitterData <-read.table("TelegansReproductiveData.csv", header=T, sep = ",", as.is=T)

#Reduce data to moms and populations
str(LitterData)
MomsData <- LitterData[,c(1,2,3,9,10,11,12)]
MomsData <- distinct(MomsData)
str(MomsData)

MomsData$PropSampled <- MomsData$SampledLitterSize/(MomsData$LiveBorn + MomsData$Stillborns)
mean(MomsData$PropSampled)
#86.3% sampled...why did this differ from above!?

#Create table of number of moms by population
MomCounts <- aggregate(MomsData$MomID, list(MomsData$Population), length)
colnames(MomCounts) <- c("Population", "MomNumber")
MomCounts

#Reduce data to just one line for each dad
Dads <- unique(LitterData$DadID)
length(Dads)
#N=68 when reduced to litters for which >55% of offspring were genotyped

#Reduce data to dads and populations
str(LitterData)
DadsData <- LitterData[,c(2,4)]
DadsData <- distinct(DadsData)
str(DadsData)
DadsData

#Create table of number of dads by population
tapply(DadsData$DadID, DadsData$Population, length)
str(DadsData)
DadsData

#Create table of number of dads by population
DadCounts <- aggregate(DadsData$Dad, list(DadsData$Population), length)
colnames(DadCounts) <- c("Population", "DadNumber")
DadCounts

#Calculate Mom reproductive success by population
#BabyCounts1 <- aggregate(LitterData$Mom, list(LitterData$Population), length)
#colnames(BabyCounts1) <- c("Population", "BabyNumber")
#BabyCounts1
#sum(BabyCounts1$BabyNumber)
#I see! This doesn't include non-sampled babies...so for moms, ReproSuccess is out of total
#Not sure sampled

str(MomsData)
TotalBabyCounts <- aggregate(MomsData$LiveBorn, list(MomsData$Population), sum)
colnames(TotalBabyCounts) <- c("Population", "TotalBabyNumber")
TotalBabyCounts

#Totals by ecotype
LfastTotalBabies <- sum(TotalBabyCounts[c(1,5,6),2])
LfastTotalBabies

MslowTotalBabies <- sum(TotalBabyCounts[2:4,2])
MslowTotalBabies

#Total number of live-born babies
sum(MomsData$Neonate)
#463 total live-born babies

#Total number of live-born + stillborn
sum(MomsData$Live.SB)
#475 total live-born + stillborn

ReproSuccess <- merge(TotalBabyCounts, MomCounts, by = "Population")
ReproSuccess$MomSuccess <- ReproSuccess$TotalBabyNumber/ReproSuccess$MomNumber
str(ReproSuccess)
ReproSuccess

#L-fast Mom ReproSuccess mean
mean(sum(ReproSuccess$TotalBabyNumber[c(1,2,3)])/sum(ReproSuccess$MomNumber[c(1,2,3)]))

#M-slow Mom ReproSuccess mean
mean(sum(ReproSuccess$TotalBabyNumber[c(4,5,6)])/sum(ReproSuccess$MomNumber[c(4,5,6)]))

#Calculate Dad reproductive success by population
#What to do with the one stillborn that's included here? Keep in analysis
SampledBabyCounts <- aggregate(LitterData$DadID, list(LitterData$Population), length)
colnames(SampledBabyCounts) <- c("Population", "SampledBabyNumber")
SampledBabyCounts
sum(SampledBabyCounts$SampledBabyNumber)
#411 sampled babies
411/463
#Remember that we removed one stillborn from Litter 230
ReproSuccess <- merge(ReproSuccess, DadCounts, by = "Population")
ReproSuccess <- merge(ReproSuccess, SampledBabyCounts, by = "Population")
ReproSuccess$DadSuccess <- ReproSuccess$SampledBabyNumber/ReproSuccess$DadNumber
str(ReproSuccess)
ReproSuccess

#L-fast Dad ReproSuccess mean
mean(sum(ReproSuccess$SampledBabyNumber[c(1,5,6)])/sum(ReproSuccess$DadNumber[c(1,5,6)]))

#M-slow Mom ReproSuccess mean
mean(sum(ReproSuccess$SampledBabyNumber[c(2,3,4)])/sum(ReproSuccess$DadNumber[c(2,3,4)]))

####Everything matches perfectly to this point, so not continuing####


#Calculate % of litters with multiple sires
str(LitterData)

#Sort litter data by Dad to count # of offspring from known dads
KnownDadData <- LitterData
KnownDadData$w.ipopdad <- as.integer(KnownDadData$w.ipopdad)
KnownDadData$Keep <- is.na(KnownDadData$w.ipopdad)
KnownDadData <- KnownDadData[KnownDadData$Keep == TRUE,]
length(KnownDadData$BabyID)
#34 babies with known dads
length(unique(KnownDadData$Dad))
str(KnownDadData)
#6 Known Dads

#Write function to count number of unique dads in each litter
UniqueLengthFunction <- function(x){length(unique(x))}

#Create data frame of number of dads contributing to each litter
MultipleSire <- aggregate(LitterData$Dad, list(LitterData$Mom), UniqueLengthFunction)
colnames(MultipleSire) <- c("Mom", "NumberDads")
str(MultipleSire)

#Merge this information back with moms data
MomsData <- merge(MomsData, MultipleSire, by = "Mom")
str(MomsData)
MomsData

head(sort(MomsData$NumberDads, decreasing = TRUE))

MomsData$MultipleSire[MomsData$NumberDads > 1] <- "Y"
MomsData$MultipleSire[MomsData$NumberDads == 1] <- "N"

#Chi-square test to compare proportion of multiply-sired litters b/t ecotypes
MultipleSireTable <- table(MomsData$Ecotype, MomsData$MultipleSire)
MultipleSireTable

PropTable <- prop.table(MultipleSireTable, 1)
PropTable

chisq.test(MultipleSireTable)

#Mean number of sires
MeanSiresLfast <- mean(MomsData$NumberDads[MomsData$Ecotype == "Lfast"],)
MeanSiresLfast

SDSiresLfast <- sqrt(var(MomsData$NumberDads[MomsData$Ecotype == "Lfast"],))
SDSiresLfast

MeanSiresMslow <- mean(MomsData$NumberDads[MomsData$Ecotype == "Mslow"],)
MeanSiresMslow

SDSiresMslow <- sqrt(var(MomsData$NumberDads[MomsData$Ecotype == "Mslow"],))
SDSiresMslow

#Calculate mean number of sires per litter by population
aggregate(MomsData$NumberDads, list(MomsData$Population), mean)

#Caculate number of fully-sampled litters for two ecotypes
length(MomsData$PropSampled[MomsData$Ecotype == "Lfast" & MomsData$PropSampled == 1])
length(MomsData$PropSampled[MomsData$Ecotype == "Mslow" & MomsData$PropSampled == 1])

#Function to calculate proportion of multiple-sired litters
PercentMultipleFunction <- function(x){length(x[x=="Y"])/length(x)}

#Create data frame of proportion of multipole-sired litters by population
PropMultiSire_Population <- aggregate(MomsData$MultipleSire, list(MomsData$Population), PercentMultipleFunction)
colnames(PropMultiSire_Population) <- c("Population", "PropMultiSire")
str(PropMultiSire_Population)
PropMultiSire_Population

#Create data frame of proportion of multipole-sired litters by ecotype
PropMultiSire_Ecotype <- aggregate(MomsData$MultipleSire, list(MomsData$Ecotype), PercentMultipleFunction)
colnames(PropMultiSire_Ecotype) <- c("Ecotype", "PropMultiSire")
str(PropMultiSire_Ecotype)
PropMultiSire_Ecotype

#Calculte I-V
#Function to calculate IV
IVFunction <- function(x){var(x)/mean(x)}

#Create data frame of IV by population
IV_Population <- aggregate(MomsData$Neonate, list(MomsData$Population), IVFunction)
colnames(IV_Population) <- c("Population", "IV")
str(IV_Population)
IV_Population

#Create data frame of IV by Ecotype
IV_Ecotype <- aggregate(MomsData$Neonate, list(MomsData$Ecotype), IVFunction)
colnames(IV_Ecotype) <- c("Ecotype", "IV")
str(IV_Ecotype)
IV_Ecotype

#Count Reproductive Success for each dad
DadSuccess <- aggregate(LitterData$Dad, list(LitterData$Dad), length)
colnames(DadSuccess) <- c("Dad", "ReproSuccess")
DadSuccess

DadsData <- merge(DadsData, DadSuccess, by = "Dad")

DadsData$Ecotype[DadsData$Population == "ELFS"] <- "Lfast"
DadsData$Ecotype[DadsData$Population == "PK"] <- "Lfast"
DadsData$Ecotype[DadsData$Population == "WC"] <- "Lfast"
DadsData$Ecotype[DadsData$Population == "MH"] <- "Mslow"
DadsData$Ecotype[DadsData$Population == "NL"] <- "Mslow"
DadsData$Ecotype[DadsData$Population == "PA"] <- "Mslow"

#Create data frame of IV by population
IV_Population <- aggregate(DadsData$ReproSuccess, list(DadsData$Population), IVFunction)
colnames(IV_Population) <- c("Population", "IV")
str(IV_Population)
IV_Population

#Create data frame of IV by Ecotype
IV_Ecotype <- aggregate(DadsData$ReproSuccess, list(DadsData$Ecotype), IVFunction)
colnames(IV_Ecotype) <- c("Ecotype", "IV")
str(IV_Ecotype)
IV_Ecotype

#Confirming above results by ecotype
Lfastvar<-var(DadsData$ReproSuccess[DadsData$Ecotype == "Lfast"])
Lfastmean<-mean(DadsData$ReproSuccess[DadsData$Ecotype == "Lfast"])
LfastIV <- Lfastvar/Lfastmean
LfastIV

Mslowvar<-var(DadsData$ReproSuccess[DadsData$Ecotype == "Mslow"])
Mslowmean<-mean(DadsData$ReproSuccess[DadsData$Ecotype == "Mslow"])
MslowIV <- Mslowvar/Mslowmean
MslowIV

#Calculate reproductive skew

#Practice data frame
#Litter379Data <- LitterData[LitterData$Mom == 379,]

#Effective number of sires formula
EffectSiresFunction <- function(x){1/sum(x)}

#Function to calculate within-litter skew for each litter where MultiplePaternity = Y
WithinLitterSkew_Function <- function(x){

#One line for each sire with number of offspring
#x <- Litter379Data$Dad

sires <- aggregate(x, list(x), length)
colnames(sires) <- c("Dad", "RS")

sires$SampledLitterSize <- sum(sires$RS)
sires$EffSires_Step1 <- (sires$RS/sires$SampledLitterSize)^2

LitterEffectiveSize <- EffectSiresFunction(sires$EffSires_Step1)
LitterEffectiveSize

WithinLitterSkew <- 1-(LitterEffectiveSize/length(sires$Dad))
WithinLitterSkew

}

ReproSkewData <- aggregate(LitterData$Dad, list(LitterData$Mom), WithinLitterSkew_Function)
colnames(ReproSkewData) <- c("Mom", "ReproSkew")
ReproSkewData

#Now add ReproSkew back to mom data to calculate values by pop/ecotype
MomsData <- merge(MomsData, ReproSkewData, by = "Mom")
str(MomsData)

#Should these include Zeros (that is, litters with one dad?)
#Create data frame of Reproductive Skew by population
#ReproSkew_Population <- aggregate(MomsData$ReproSkew[MomsData$MultipleSire == "Y"], list(MomsData$Population[MomsData$MultipleSire == "Y"]), mean)
ReproSkew_Population <- aggregate(MomsData$ReproSkew, list(MomsData$Population), mean)
colnames(ReproSkew_Population) <- c("Population", "ReproSkew")
str(ReproSkew_Population)
ReproSkew_Population

#Create data frame of Reproductive Skew by Ecotype
#ReproSkew_Ecotype <- aggregate(MomsData$ReproSkew[MomsData$MultipleSire == "Y"], list(MomsData$Ecotype[MomsData$MultipleSire == "Y"]), mean)
ReproSkew_Ecotype <- aggregate(MomsData$ReproSkew, list(MomsData$Ecotype), mean)
colnames(ReproSkew_Ecotype) <- c("Ecotype", "ReproSkew")
str(ReproSkew_Ecotype)
ReproSkew_Ecotype

#Test significant differences from zero for Reproductive Skew
t.test(MomsData$ReproSkew[MomsData$Ecotype == "Lfast"], mu=0, alternative = "greater")
t.test(MomsData$ReproSkew[MomsData$Ecotype == "Mslow"], mu=0, alternative = "greater")

t.test(MomsData$ReproSkew[MomsData$Population == "ELFS"], mu=0, alternative = "greater")
t.test(MomsData$ReproSkew[MomsData$Population == "PK"], mu=0, alternative = "greater")
t.test(MomsData$ReproSkew[MomsData$Population == "WC"], mu=0, alternative = "greater")
t.test(MomsData$ReproSkew[MomsData$Population == "MH"], mu=0, alternative = "greater")
t.test(MomsData$ReproSkew[MomsData$Population == "NL"], mu=0, alternative = "greater")
t.test(MomsData$ReproSkew[MomsData$Population == "PA"], mu=0, alternative = "greater")

#Test whether populations differed from each other
t.test(MomsData$ReproSkew[MomsData$Ecotype == "Mslow"], MomsData$ReproSkew[MomsData$Ecotype == "Lfast"])
#Nope

#Create data frame of Observed Sires by population
ObservedSires_Population <- aggregate(MomsData$NumberDads, list(MomsData$Population), mean)
colnames(ObservedSires_Population) <- c("Population", "ObservedSires")
str(ObservedSires_Population)
ObservedSires_Population

#Create data frame of Observed Sires by Ecotype
ObservedSires_Ecotype <- aggregate(MomsData$NumberDads, list(MomsData$Ecotype), mean)
colnames(ObservedSires_Ecotype) <- c("Ecotype", "ObservedSires")
str(ObservedSires_Ecotype)
ObservedSires_Ecotype

####GLMMs####
#Need to add SVL
#input Mom SVL data file
setwd("C:/Users/ejgangloff/Box/BronikoLabExperiments/TelegansMultiplePaternity/2020Revision")
MomSVLData <-read.table("MomSVLData.csv", header=T, sep = ",", as.is=T)

MomsData <- merge(MomsData, MomSVLData, by = "Mom", all.x = T, all.y = F)
str(MomsData)
str(DadsData)

#Output data files (for analysis in SAS?)
#write.table(MomsData, file="MomReproData_3Jul2020.csv", sep=",", quote=FALSE, row.names = FALSE)
#write.table(DadsData, file="DadReproData_3Jul2020.csv", sep=",", quote=FALSE, row.names = FALSE)

#Kolmogorov-Smirnov tests
#Compare Reproductive Success of Moms between Ecotypes
ks.test(MomsData$Neonate[MomsData$Ecotype == "Lfast"], MomsData$Neonate[MomsData$Ecotype == "Mslow"], exact = FALSE)
#D = 0.77436, p-value = 1.113e-07
#alternative hypothesis: two-sided

#Compare Reproductive Success of Dads between Ecotypes
ks.test(DadsData$ReproSuccess[DadsData$Ecotype == "Lfast"], DadsData$ReproSuccess[DadsData$Ecotype == "Mslow"], exact = FALSE)
#D = 0.40053, p-value = 0.009626
#alternative hypothesis: two-sided

#Compare Reproductive Success between moms and dads within each ecotype
MomSuccess_Reduced <- MomsData[, c(1,6,9)]
MomSuccess_Reduced$Sex <- rep("F", length(MomSuccess_Reduced$Mom))
colnames(MomSuccess_Reduced) <- c("ID", "ReproSuccess", "Ecotype", "Sex")
head(MomSuccess_Reduced)

DadSuccess_Reduced <- DadsData[, c(1,3,4)]
DadSuccess_Reduced$Sex <- rep("M", length(DadSuccess_Reduced$Dad))
colnames(DadSuccess_Reduced) <- c("ID", "ReproSuccess", "Ecotype", "Sex")
head(DadSuccess_Reduced)

MergedReproSuccessData <- rbind(MomSuccess_Reduced, DadSuccess_Reduced)
MergedReproSuccessData

#Compare Reproductive Success of Moms and Dads in M-slow
ks.test(MergedReproSuccessData$ReproSuccess[MergedReproSuccessData$Ecotype == "Mslow" & MergedReproSuccessData$Sex == "F"],
        MergedReproSuccessData$ReproSuccess[MergedReproSuccessData$Ecotype == "Mslow" & MergedReproSuccessData$Sex == "M"],
        exact = FALSE)
#D = 0.22546, p-value = 0.4887
#alternative hypothesis: two-sided

#Compare Reproductive Success of Moms and Dads in L-fast
ks.test(MergedReproSuccessData$ReproSuccess[MergedReproSuccessData$Ecotype == "Lfast" & MergedReproSuccessData$Sex == "F"],
        MergedReproSuccessData$ReproSuccess[MergedReproSuccessData$Ecotype == "Lfast" & MergedReproSuccessData$Sex == "M"],
        exact = FALSE)
#D = 0.46667, p-value = 0.00124
#alternative hypothesis: two-sided


##Ordinal Logistic Regression##
# Load the library
library(MASS)

#Run Ordinal Logistic Regression Model
str(MomsData)

MomsData$NumberDads <- as.factor(as.character(MomsData$NumberDads))

NumberDadsModel <- polr(NumberDads ~ SampledLitterSize + Ecotype + SVL, Hess = TRUE, data=MomsData)
NumberDadsModel
summary(NumberDadsModel)

##Make table of coefficients
ctable <- coef(summary(NumberDadsModel))

## calculate and store p values
p <- pnorm(abs(ctable[, "t value"]), lower.tail = FALSE) * 2

## combined table (with p-values, though these might not be great)
ctable <- cbind(ctable, "p value" = p)
ctable

#Get CIs
ci <- confint(NumberDadsModel) # default method gives profiled CIs
confint.default(NumberDadsModel) # CIs assuming normality

####Create Data Files for Reproductive Skew Simulations a la Neff####
NeffData_1 <- MomsData[, c(1,2,3,7,9)]
NeffData_1

#Can then output columns 3 & 4 by population/ecotype

#Function to number of offspring sired by dad within each litter
DadContribution_Function <- function(x){
  
  #One line for each sire with number of offspring
  #x <- Litter379Data$Dad
  
  sires <- aggregate(x, list(x), length)
  colnames(sires) <- c("Dad", "RS")
  
  DadVector <- sires$RS

}

DadContributionData <- aggregate(LitterData$Dad, list(LitterData$Mom), DadContribution_Function)
str(DadContributionData)
DadContributionData

DadContributionData[,3] <- NA
DadContributionData[,4] <- NA
DadContributionData[,5] <- NA
DadContributionData[,6] <- NA

#DadContributionData[2,2] <- DadContributionData[2,3]

for(k in 1:length(DadContributionData[,1])){
  for(i in 1:4) {
          DadContributionData[k,i+2] <- DadContributionData[k,2][[1]][i]}
}


#DadContributionData[2,3] <- DadContributionData[2,2][[1]][1]
head(DadContributionData)

DadContributionData <- DadContributionData[, c(1,3,4,5,6)]
colnames(DadContributionData) <- c("Mom", "Dad_1", "Dad_2", "Dad_3", "Dad_4")
DadContributionData

#Add back in population and ecotype
NeffData_2 <- merge(NeffData_1[,c(1,2,5)], DadContributionData, by = "Mom")
NeffData_2

#Can then output NeffData_1 columns 3 & 4 by population/ecotype
#Can then output NeffData_2 columns 4-7 by population/ecotype
#write.table(NeffData_1[,c(3,4)], file="NeffData_1_All.csv", sep=",", quote=FALSE, row.names = FALSE)
#write.table(NeffData_2[,4:7], file="NeffData_2_All.csv", sep=",", quote=FALSE, row.names = FALSE)


####Figures####
library(ggplot2)
library(cowplot)

fig_theme <- theme_classic(base_size = 28) + theme(axis.title.y=element_text(vjust=.5), axis.title.x=element_text(vjust=1)) + #adjust axis and text size and position
        theme(axis.line.x=element_line(size = 1.25), axis.line.y=element_line(size = 1.25), plot.margin = unit(c(.1,.1,.1,.1), "cm"),
        axis.ticks=element_line(size = 1.25, colour="black")) + #adjust plot margins and line element size
        theme(axis.ticks.length = unit(-0.3, "cm"), legend.key.width=unit(60, "points"),
        legend.title=element_blank(),
        axis.ticks.x = element_blank(),
        axis.text.y=element_text(margin = margin(r = 12), colour="black"),
        axis.text.x=element_text(margin = margin(t = 12), colour="black"),
        legend.position = c(0.8, 0.9), legend.direction = "vertical")
         
#Moms b/t ecotypes
FemalesbyEcotypePlot <- ggplot(MomsData, aes(x=Neonate, fill=Ecotype, group=Ecotype)) +
  geom_histogram(position="dodge", binwidth = 1, col="white") +
  fig_theme +
  labs(title=element_blank(), x="Number of Offspring", y="Count") +
  scale_fill_manual(values = c("darkred", "darkblue"), labels = c("L-fast Dams", "M-slow Dams")) +
  scale_x_continuous(limits = c(0,18), breaks = c(0,5,10,15)) +
  scale_y_continuous(limits = c(0,8)) +
  annotate(geom="text", x=0.5, y=7.5, label='bold("A")', size = 18, parse=TRUE)

FemalesbyEcotypePlot
#ggsave(FemalesbyEcotypePlot, file="FemalesbyEcotypePlot.tiff", dpi = 250, width = 10, height = 6)
#Note that graph dimensions are in inches, so to specify in terms of pixels need to divide by dpi

#Dads b/t ecotypes
MalesbyEcotypePlot <- ggplot(DadsData, aes(x=ReproSuccess, fill=Ecotype, group=Ecotype)) +
  geom_histogram(position="dodge", binwidth = 1, col="white") +
  fig_theme +
  labs(title=element_blank(), x="Number of Offspring", y="Count") +
  scale_fill_manual(values = c("darkred", "darkblue"), labels = c("L-fast Sires", "M-slow Sires")) +
  scale_x_continuous(limits = c(0,18), breaks = c(0,5,10,15)) +
  scale_y_continuous(limits = c(0,8)) +
  annotate(geom="text", x=0.5, y=7.5, label='bold("B")', size = 18, parse=TRUE)

MalesbyEcotypePlot
ggsave(MalesbyEcotypePlot, file="MalesbyEcotypePlot.tiff", dpi = 250, width = 10, height = 6)
#Note that graph dimensions are in inches, so to specify in terms of pixels need to divide by dpi

#Within ecotype M-slow
MslowSexPlot <- ggplot(MergedReproSuccessData[MergedReproSuccessData$Ecotype == "Mslow",],
       aes(x=ReproSuccess, fill=Sex, group=Sex)) +
  geom_histogram(position="dodge", binwidth = 1, col="white") +
  fig_theme +
  labs(title=element_blank(), x="Number of Offspring", y="Count") +
  scale_fill_manual(values = c("darkblue", "lightblue"), labels = c("M-slow Dams", "M-slow Sires")) +
  scale_x_continuous(limits = c(0,18), breaks = c(0,5,10,15)) +
  scale_y_continuous(limits = c(0,8)) +
  annotate(geom="text", x=0.5, y=7.5, label='bold("D")', size = 18, parse=TRUE)

MslowSexPlot
ggsave(MslowSexPlot, file="MslowSexPlot.tiff", dpi = 250, width = 10, height = 6)
#Note that graph dimensions are in inches, so to specify in terms of pixels need to divide by dpi


#Within ecotype L-fast
LfastSexPlot <- ggplot(MergedReproSuccessData[MergedReproSuccessData$Ecotype == "Lfast",],
       aes(x=ReproSuccess, fill=Sex, group=Sex)) +
  geom_histogram(position="dodge", binwidth = 1, col="white") +
  fig_theme +
  labs(title=element_blank(), x="Number of Offspring", y="Count") +
  scale_fill_manual(values = c("darkred", "red"), labels = c("L-fast Dams", "L-fast Sires")) +
  scale_x_continuous(limits = c(0,18), breaks = c(0,5,10,15)) +
  scale_y_continuous(limits = c(0,8)) +
  annotate(geom="text", x=0.5, y=7.5, label='bold("C")', size = 18, parse=TRUE)

LfastSexPlot
ggsave(LfastSexPlot, file="LfastSexPlotPlot.tiff", dpi = 250, width = 10, height = 6)
#Note that graph dimensions are in inches, so to specify in terms of pixels need to divide by dpi

